@@ -5,14 +5,14 @@
 
 #include "testolmaccount.h"
 
-#include <connection.h>
-#include <csapi/joining.h>
-#include <e2ee/qolmaccount.h>
-#include <e2ee/qolmutility.h>
-#include <events/encryptionevent.h>
-#include <events/filesourceinfo.h>
-#include <networkaccessmanager.h>
-#include <room.h>
+#include <Quotient/connection.h>
+#include <Quotient/csapi/joining.h>
+#include <Quotient/e2ee/qolmaccount.h>
+#include <Quotient/e2ee/qolmutility.h>
+#include <Quotient/events/encryptionevent.h>
+#include <Quotient/events/filesourceinfo.h>
+#include <Quotient/networkaccessmanager.h>
+#include <Quotient/room.h>
 
 #include "testutils.h"
 
@@ -82,20 +82,20 @@ void TestOlmAccount::deviceKeys()
 {
     // copied from mtxclient
     DeviceKeys device1;
-    device1.userId = "@alice:example.com";
-    device1.deviceId = "JLAFKJWSCS";
-    device1.keys = {{"curve25519:JLAFKJWSCS", "3C5BFWi2Y8MaVvjM8M22DBmh24PmgR0nPvJOIArzgyI"},
-                    {"ed25519:JLAFKJWSCS", "lEuiRJBit0IG6nUf5pUzWTUEsRVVe/HJkoKuEww9ULI"}};
+    device1.userId = "@alice:example.com"_ls;
+    device1.deviceId = "JLAFKJWSCS"_ls;
+    device1.keys = {{"curve25519:JLAFKJWSCS"_ls, "3C5BFWi2Y8MaVvjM8M22DBmh24PmgR0nPvJOIArzgyI"_ls},
+                    {"ed25519:JLAFKJWSCS"_ls, "lEuiRJBit0IG6nUf5pUzWTUEsRVVe/HJkoKuEww9ULI"_ls}};
 
     // TODO that should be the default value
     device1.algorithms =
         QStringList { OlmV1Curve25519AesSha2AlgoKey, MegolmV1AesSha2AlgoKey };
 
     device1.signatures = {
-      {"@alice:example.com",
-       {{"ed25519:JLAFKJWSCS",
+      {"@alice:example.com"_ls,
+       {{"ed25519:JLAFKJWSCS"_ls,
          "dSO80A01XiigH3uBiDVx/EjzaoycHcjq9lfQX0uWsqxl2giMIiSPR8a4d291W1ihKJL/"
-         "a+myXS367WT6NAIcBA"}}}};
+         "a+myXS367WT6NAIcBA"_ls}}}};
 
     QJsonObject j;
     JsonObjectConverter<DeviceKeys>::dumpTo(j, device1);
@@ -161,19 +161,19 @@ void TestOlmAccount::encryptedFile()
 
     const auto file = fromJson<EncryptedFileMetadata>(doc);
 
-    QCOMPARE(file.v, "v2");
-    QCOMPARE(file.iv, "w+sE15fzSc0AAAAAAAAAAA");
-    QCOMPARE(file.hashes["sha256"], "fdSLu/YkRx3Wyh3KQabP3rd6+SFiKg5lsJZQHtkSAYA");
-    QCOMPARE(file.key.alg, "A256CTR");
+    QCOMPARE(file.v, "v2"_ls);
+    QCOMPARE(file.iv, "w+sE15fzSc0AAAAAAAAAAA"_ls);
+    QCOMPARE(file.hashes["sha256"_ls], "fdSLu/YkRx3Wyh3KQabP3rd6+SFiKg5lsJZQHtkSAYA"_ls);
+    QCOMPARE(file.key.alg, "A256CTR"_ls);
     QCOMPARE(file.key.ext, true);
-    QCOMPARE(file.key.k, "aWF6-32KGYaC3A_FEUCk1Bt0JA37zP0wrStgmdCaW-0");
+    QCOMPARE(file.key.k, "aWF6-32KGYaC3A_FEUCk1Bt0JA37zP0wrStgmdCaW-0"_ls);
     QCOMPARE(file.key.keyOps.count(), 2);
-    QCOMPARE(file.key.kty, "oct");
+    QCOMPARE(file.key.kty, "oct"_ls);
 }
 
 void TestOlmAccount::uploadIdentityKey()
 {
-    CREATE_CONNECTION(conn, "alice1", "secret", "AlicePhone")
+    CREATE_CONNECTION(conn, "alice1"_ls, "secret"_ls, "AlicePhone"_ls)
 
     auto olmAccount = conn->olmAccount();
     auto idKeys = olmAccount->identityKeys();
@@ -198,7 +198,7 @@ void TestOlmAccount::uploadIdentityKey()
 
 void TestOlmAccount::uploadOneTimeKeys()
 {
-    CREATE_CONNECTION(conn, "alice2", "secret", "AlicePhone")
+    CREATE_CONNECTION(conn, "alice2"_ls, "secret"_ls, "AlicePhone"_ls)
     auto olmAccount = conn->olmAccount();
 
     auto nKeys = olmAccount->generateOneTimeKeys(5);
@@ -209,7 +209,7 @@ void TestOlmAccount::uploadOneTimeKeys()
     OneTimeKeys oneTimeKeysHash;
     const auto curve = oneTimeKeys.curve25519();
     for (const auto &[keyId, key] : asKeyValueRange(curve)) {
-        oneTimeKeysHash["curve25519:"+keyId] = key;
+        oneTimeKeysHash["curve25519:"_ls + keyId] = key;
     }
     auto request = new UploadKeysJob(none, oneTimeKeysHash);
     connect(request, &BaseJob::result, this, [request, conn] {
@@ -224,7 +224,7 @@ void TestOlmAccount::uploadOneTimeKeys()
 
 void TestOlmAccount::uploadSignedOneTimeKeys()
 {
-    CREATE_CONNECTION(conn, "alice3", "secret", "AlicePhone")
+    CREATE_CONNECTION(conn, "alice3"_ls, "secret"_ls, "AlicePhone"_ls)
     auto olmAccount = conn->olmAccount();
     auto nKeys = olmAccount->generateOneTimeKeys(5);
     QCOMPARE(nKeys, 5);
@@ -248,7 +248,7 @@ void TestOlmAccount::uploadSignedOneTimeKeys()
 
 void TestOlmAccount::uploadKeys()
 {
-    CREATE_CONNECTION(conn, "alice4", "secret", "AlicePhone")
+    CREATE_CONNECTION(conn, "alice4"_ls, "secret"_ls, "AlicePhone"_ls)
     auto olmAccount = conn->olmAccount();
     auto idks = olmAccount->identityKeys();
     olmAccount->generateOneTimeKeys(1);
@@ -266,8 +266,8 @@ void TestOlmAccount::uploadKeys()
 
 void TestOlmAccount::queryTest()
 {
-    CREATE_CONNECTION(alice, "alice5", "secret", "AlicePhone")
-    CREATE_CONNECTION(bob, "bob1", "secret", "BobPhone")
+    CREATE_CONNECTION(alice, "alice5"_ls, "secret"_ls, "AlicePhone"_ls)
+    CREATE_CONNECTION(bob, "bob1"_ls, "secret"_ls, "BobPhone"_ls)
 
     // Create and upload keys for both users.
     auto aliceOlm = alice->olmAccount();
@@ -334,8 +334,8 @@ void TestOlmAccount::queryTest()
 
 void TestOlmAccount::claimKeys()
 {
-    CREATE_CONNECTION(alice, "alice6", "secret", "AlicePhone")
-    CREATE_CONNECTION(bob, "bob2", "secret", "BobPhone")
+    CREATE_CONNECTION(alice, "alice6"_ls, "secret"_ls, "AlicePhone"_ls)
+    CREATE_CONNECTION(bob, "bob2"_ls, "secret"_ls, "BobPhone"_ls)
 
     // Bob uploads his keys.
     auto *bobOlm = bob->olmAccount();
@@ -364,7 +364,7 @@ void TestOlmAccount::claimKeys()
 
     // Retrieve the identity key for the current device to check after claiming
     const auto& bobEd25519 = bobDevices.value(bob->deviceId())
-                                 .keys.value("ed25519:" + bob->deviceId());
+                                 .keys.value("ed25519:%1"_ls.arg(bob->deviceId()));
 
     const QHash<QString, QHash<QString, QString>> oneTimeKeys{
         { bob->userId(), { { bob->deviceId(), SignedCurve25519Key } } }
@@ -392,9 +392,9 @@ void TestOlmAccount::claimKeys()
 void TestOlmAccount::claimMultipleKeys()
 {
     // Login with alice multiple times
-    CREATE_CONNECTION(alice, "alice7", "secret", "AlicePhone")
-    CREATE_CONNECTION(alice1, "alice7", "secret", "AlicePhone")
-    CREATE_CONNECTION(alice2, "alice7", "secret", "AlicePhone")
+    CREATE_CONNECTION(alice, "alice7"_ls, "secret"_ls, "AlicePhone"_ls)
+    CREATE_CONNECTION(alice1, "alice7"_ls, "secret"_ls, "AlicePhone"_ls)
+    CREATE_CONNECTION(alice2, "alice7"_ls, "secret"_ls, "AlicePhone"_ls)
 
     auto olm = alice->olmAccount();
     olm->generateOneTimeKeys(10);
@@ -427,7 +427,7 @@ void TestOlmAccount::claimMultipleKeys()
     QVERIFY(spy2.wait(10000));
 
     // Bob will claim all keys from alice
-    CREATE_CONNECTION(bob, "bob3", "secret", "BobPhone")
+    CREATE_CONNECTION(bob, "bob3"_ls, "secret"_ls, "BobPhone"_ls)
 
     QStringList devices_;
     devices_ << alice->deviceId()
@@ -449,7 +449,7 @@ void TestOlmAccount::claimMultipleKeys()
 
 void TestOlmAccount::enableEncryption()
 {
-    CREATE_CONNECTION(alice, "alice9", "secret", "AlicePhone")
+    CREATE_CONNECTION(alice, "alice9"_ls, "secret"_ls, "AlicePhone"_ls)
 
     auto job = alice->createRoom(Connection::PublishRoom, {}, {}, {}, {});
     QSignalSpy createRoomSpy(job, &BaseJob::success);
